Method: Delphi::Compiler#initialize

Defined in:
lib/delphi/compiler.rb

#initialize(project_version, fail_on_hints_and_warnings = true) ⇒ Compiler

You need to pass the Delphi target version to this class. If you use the Project or GroupProj classes, they will figure this out for you from the information in the dproj file.



17
18
19
20
21
# File 'lib/delphi/compiler.rb', line 17

def initialize(project_version, fail_on_hints_and_warnings = true)
  Delphi::Environment.instance.configure(project_version)
  @fail_on_hints_and_warnings = fail_on_hints_and_warnings
  @fail_on_errors = true
end